/*
 * Copyright 2005-2011 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.wicket.behavior;

import org.apache.wicket.AttributeModifier;
import org.apache.wicket.model.IModel;
import org.apache.wicket.model.Model;

/**
 * Attribute modifier to add onclick confirmation to buttons. 
 * 
 * @author Erik Brakkee
 */
public class OnClickConfirmationBehavior extends AttributeModifier {

    private static final String ATTRIBUTE = "onclick";

    /**
     * Constructs the behavior.
     * @param aMsg Confirmation message.
     */
    public OnClickConfirmationBehavior(String aMsg) {
        this(new Model(aMsg));
    }
    
    /**
     * Constructs the behavior.
     * @param aMsgModel Confirmation message. 
     */
    public OnClickConfirmationBehavior(IModel<?> aMsgModel) {
        super(ATTRIBUTE, true, aMsgModel);
    }

    @Override
    protected String newValue(String aCurrentValue, String aReplacementValue) {
        String value = "var conf = confirm('" + aReplacementValue + "'); " +
            "if (!conf) return false; ";
        if (aCurrentValue != null) {
            return value + aCurrentValue;
        }
        return value;
    }

}
