/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.wicket.jquery;

import org.apache.wicket.Application;
import org.apache.wicket.behavior.HeaderContributor;
import org.apache.wicket.markup.html.IHeaderContributor;
import org.apache.wicket.markup.html.IHeaderResponse;
import org.apache.wicket.markup.html.JavascriptPackageResource;

/**
 * JQuery header contribution that adds the jquery javascript and sets jQuery to 
 * no-conflict mode so the <code>$</code> identifier is freed. Also, it checks
 * the current configuration and uses the development mode jQuery library when run in 
 * development mode and used the minimalized jQuery code when running in deployment mode.
 * 
 * @author Erik Brakkee
 */
public class JQueryHeaderContributor extends HeaderContributor {

    static final String JQUERY_DEPLOYMENT = "jquery-1.5.min.js";
    static final String JQUERY_DEVELOPMENT = "jquery-1.5.js";
    static final String JQUERY_NOCONFLICT = "jquery-noconflict.js";

    private static HeaderContributor JQUERY_CONTRIBUTOR;
    private static HeaderContributor JQUERY_NOCONFLICT_CONTRIBUTOR =
        JavascriptPackageResource.getHeaderContribution(
            JQueryHeaderContributor.class, JQUERY_NOCONFLICT);

    /**
     * Constructs the behavior.
     */
    public JQueryHeaderContributor() {
        super(getContributor());
    }
    
    /**
     * Resets the cached value of the header contribution. Used typically for test only.
     */
    public static void clear() { 
        JQUERY_CONTRIBUTOR = null;
    }

    private static IHeaderContributor getContributor() {
        if (JQUERY_CONTRIBUTOR == null) {
            JQUERY_CONTRIBUTOR = JavascriptPackageResource.getHeaderContribution(
                JQueryHeaderContributor.class, getJQueryJavascript());
        }
        return new IHeaderContributor() {        
            @Override
            public void renderHead(IHeaderResponse aResponse) {
                JQUERY_CONTRIBUTOR.renderHead(aResponse);
                JQUERY_NOCONFLICT_CONTRIBUTOR.renderHead(aResponse);
            }
        };
    }

    private static String getJQueryJavascript() {
        return Application.get().getConfigurationType().equals(
            Application.DEVELOPMENT) ? JQUERY_DEVELOPMENT : JQUERY_DEPLOYMENT;
    }
}
