/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.wicket.page;

import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.protocol.http.WebResponse;

/**
 * Abstract page behavior to simplify implementations of behaviors thar don't
 * need to implement all callbacks.
 * 
 * @author Erik Brakkee
 */
public abstract class AbstractPageBehavior implements PageBehavior {

    /**
     * Constructor.
     */
    protected AbstractPageBehavior() {
        // Empty
    }

    @Override
    public void onBeforeRender(WebPage aPage) {
        // Empty
    }

    @Override
    public void setHeaders(WebPage aPage, WebResponse aResponse) {
        // Empty
    }

    @Override
    public void onAfterRender(WebPage aPage) {
        // Empty
    }

    @Override
    public void onDetach(WebPage aPage) {
        // Empty
    }

}
