/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.wicket.page;

import java.io.Serializable;

import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.protocol.http.WebResponse;

/**
 * Page behavior interface. This provides a mechanism to extend page behavior
 * without subclassing. Implementations of this interface should be
 * serializable.
 * 
 * @author Erik Brakkee
 */
public interface PageBehavior extends Serializable {

    /**
     * To be called as part of the Page's <code>onBeforeRender</code>
     * 
     * @param aPage
     *            Page this is called for.
     */
    void onBeforeRender(WebPage aPage);

    /**
     * To be called as part of the Page's <code>setHeaders</code>
     * 
     * @param aPage
     *            Page this is called for.
     * @param aResponse
     *            Response to set headers for.
     */
    void setHeaders(WebPage aPage, WebResponse aResponse);

    /**
     * To be called as part of the Page's <code>onAfterRender</code>
     * 
     * @param aPage
     *            Page this is called for.
     */
    void onAfterRender(WebPage aPage);

    /**
     * To be called in the {@link Page#onDetach

     */
    void onDetach(WebPage aPage);
}
